# Exact SMC

This packages implements methods described in [the paper](https://doi.org/10.1101/2020.09.21.307355):

    Exact decoding of the sequentially Markov coalescent
    Caleb Ki, Jonathan Terhorst
    bioRxiv 2020.09.21.307355; doi:10.1101/2020.09.21.307355

Please visit https://terhorst.github.io/xsmc for installation instructions and usage examples.